projected_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# projected_mesh

property ElectronicBandStructure.projected_mesh

  projected mesh is a numpy array that stores each projection in a mesh grid. Shape = [n_kx,n_ky,n_kz,n_bands,n_spins,n_atoms,n_orbitals]

  Returns:

    np.ndarray – Projection mesh is a numpy array that stores each projection in a mesh grid. Shape = [n_kx,n_ky,n_kz,n_bands,n_spins,n_atoms,n_orbitals]